package com.gxlu.ps.netcruise.md.buffer;

import com.gxlu.ps.netcruise.md.Configer;
import com.gxlu.ps.netcruise.md.GlobalInstance;
import com.gxlu.ps.netcruise.md.sender.TestSender;
import com.gxlu.ps.netcruise.md.util.Alarm;
import com.gxlu.ps.netcruise.md.util.LogFileUtil;
import java.util.LinkedList;
import org.apache.log4j.Logger;

/* loaded from: com_gxlu_ps_netcruise_md_buffer.jar:com/gxlu/ps/netcruise/md/buffer/AlarmPool.class */
public class AlarmPool {
    protected AlarmQueue[] alarmQueues;
    protected AlarmFile alarmFile;
    protected int maxAlarmNumOfQueue;
    private static AlarmPool instance = null;
    private Logger logger;
    protected int mode;
    protected TestSender testSender;
    protected int flags;
    protected Object lock;

    private AlarmPool(String filePath, int maxAlarmNumOfQueue) {
        this.logger = null;
        this.testSender = null;
        GlobalInstance gi = GlobalInstance.getInstance();
        gi.getConfiger();
        this.logger = gi.getLogger();
        this.maxAlarmNumOfQueue = maxAlarmNumOfQueue;
        this.alarmFile = new AlarmFile(filePath);
        this.lock = new Object();
        this.mode = 1;
        this.alarmQueues = new AlarmQueue[3];
        this.alarmQueues[0] = new AlarmQueue(maxAlarmNumOfQueue, 1, this.alarmFile);
        this.alarmQueues[1] = new AlarmQueue(maxAlarmNumOfQueue, 2, this.alarmFile);
        this.alarmQueues[2] = new AlarmQueue(maxAlarmNumOfQueue, 3, this.alarmFile);
        this.alarmQueues[2].loadFromFile();
        synchronized (this.lock) {
            this.flags |= 4;
        }
        String runmode = GlobalInstance.getInstance().getConfiger().checkRunMode();
        if (runmode.equals("TEST")) {
            this.testSender = GlobalInstance.getInstance().getTestSender();
        } else {
            this.testSender = null;
        }
    }

    public static synchronized AlarmPool getInstance() {
        if (instance == null) {
            try {
                Configer cf = GlobalInstance.getInstance().getConfiger();
                instance = new AlarmPool(cf.getAlarmFilePath(), cf.getBufferSize());
            } catch (Exception e) {
                return (AlarmPool) null;
            }
        }
        return instance;
    }

    public synchronized void setMode(int mode) {
        this.mode = mode;
        this.alarmQueues[0].setMode(mode);
        this.alarmQueues[1].setMode(mode);
        this.alarmQueues[2].setMode(mode);
        if (1 == mode) {
            this.alarmQueues[2].loadFromFile();
            synchronized (this.lock) {
                this.flags |= 4;
            }
        }
    }

    public void saveAlarm(Alarm alarm, int level) {
        Configer cf = GlobalInstance.getInstance().getConfiger();
        new LogFileUtil().appendLog(cf.getAlarmLogPath(), alarm.getContent(), "UTF-8");
        this.logger.trace("alarmPool receive an alarm.level:".concat(String.valueOf(String.valueOf(level))));
        if (alarm == null) {
            return;
        }
        try {
            this.alarmQueues[level - 1].addAlarm(alarm);
            synchronized (this.lock) {
                this.flags |= level;
                this.lock.notify();
            }
        } catch (Exception e) {
        }
        if (this.testSender != null) {
            this.testSender.putAlarm(alarm);
        }
    }

    public void saveAlarms(LinkedList alarms, int level) {
        this.logger.trace("alarmPool receive alarms.");
        if (alarms == null) {
            return;
        }
        try {
            this.alarmQueues[level - 1].addAlarms(alarms);
            synchronized (this.lock) {
                this.flags |= level;
                this.lock.notifyAll();
            }
        } catch (Exception e) {
        }
        if (this.testSender != null) {
            this.testSender.putAlarm((Alarm) alarms.removeFirst());
        }
    }

    public Alarm getAlarm() {
        this.logger.trace("alarmPool is called to return an alarm");
        Alarm alm = this.alarmQueues[0].removeAlarm();
        if (alm != null) {
            return alm;
        }
        Alarm alm2 = this.alarmQueues[2].removeAlarm();
        if (alm2 != null) {
            return alm2;
        }
        this.alarmQueues[2].loadAllFromFile();
        Alarm alm3 = this.alarmQueues[2].removeAlarm();
        return alm3 != null ? alm3 : this.alarmQueues[1].removeAlarm();
    }

    public LinkedList getAlarms() {
        LinkedList alms;
        this.logger.trace("alarmPool is called to return alarms");
        synchronized (this.lock) {
            if (this.alarmQueues[2].size() == 0 && this.alarmQueues[2].hasAlmInFile()) {
                this.alarmQueues[2].loadFromFile();
                if (this.alarmQueues[2].size() != 0) {
                    this.flags |= 4;
                }
            }
            if (this.flags == 0) {
                try {
                    this.lock.wait();
                } catch (InterruptedException e) {
                }
            }
            switch (this.flags) {
                case 0:
                    alms = new LinkedList();
                    break;
                case 1:
                case 3:
                case 5:
                case 7:
                    this.flags &= -2;
                    alms = this.alarmQueues[0].removeAlarms();
                    break;
                case 2:
                    this.flags &= -3;
                    alms = this.alarmQueues[1].removeAlarms();
                    break;
                case 4:
                case 6:
                    this.flags &= -5;
                    alms = this.alarmQueues[2].removeAlarms();
                    break;
                default:
                    alms = new LinkedList();
                    break;
            }
        }
        return alms;
    }

    public void pushbackAlarm(Alarm alarm) {
        this.logger.trace("alarmPool is called to pushback an alarm");
        this.alarmQueues[0].pushbackAlarm(alarm);
    }

    public void pushbackAlarms(LinkedList alarms) {
        this.logger.trace("alarmPool is called to pushback alarms");
        this.alarmQueues[0].pushbackAlarms(alarms);
    }

    public void savePool() {
        this.logger.trace("alarmPool is called to save alarms to file");
        this.alarmFile.updateFile();
        this.alarmQueues[0].saveToFile();
        this.alarmQueues[2].saveToFile();
        this.alarmQueues[1].saveToFile();
    }

    public void saveAndClearPool() {
        this.logger.trace("alarmPool is called to save alarms to file and clear");
        this.alarmFile.updateFile();
        this.alarmQueues[0].saveToFileAndClear();
        this.alarmQueues[2].saveToFileAndClear();
        this.alarmQueues[1].saveToFileAndClear();
        this.alarmFile.close();
    }

    public void clearPool() {
        this.logger.trace("alarmPool is called to clear alarms");
        this.alarmQueues[0].clearAllAlarms();
        this.alarmQueues[2].clearAllAlarms();
        this.alarmQueues[1].clearAllAlarms();
    }

    public void wakeup() {
        synchronized (this.lock) {
            this.lock.notifyAll();
        }
    }

    public int size() {
        return this.alarmQueues[0].size() + this.alarmQueues[1].size() + this.alarmQueues[2].size();
    }

    public boolean fileHasAlm() {
        return this.alarmQueues[2].hasAlmInFile();
    }
}
